@@ -286,7 +286,7 @@ class WebalbumDir(make.FileMakeObject):
     def __init__(self, dir, subgals, album, album_dest_dir):
         self.source_dir = dir
         self.path = os.path.join(album_dest_dir, self.source_dir.strip_root())
-        if self.path.endswith('/'): self.path = os.path.dirname(self.path)
+        if self.path.endswith(os.sep): self.path = os.path.dirname(self.path)
 
         super(WebalbumDir, self).__init__(self.path)
 
@@ -348,6 +348,7 @@ class WebalbumDir(make.FileMakeObject):
     def __parse_browse_sizes(self, sizes_string):
         for single_def in sizes_string.split(','):
             name, string_size = single_def.split('=')
+            name = name.decode(locale.getpreferredencoding())
             if name == '':
                 raise ValueError(_("Sizes is a comma-separated list of size names and specs:\n\t e.g. \"small=640x480,medium=1024x768\"."))
             if name == genmedia.THUMB_SIZE_NAME:
@@ -362,7 +363,7 @@ class WebalbumDir(make.FileMakeObject):
             try:
                 self.newsizers[size_name] = newsize.get_newsizer(size_string)
             except newsize.NewsizeStringParseError:
-                raise ValueError(_("'%s' for size '%s' does not describe a known size syntax.") % (size_string, size_name, ))
+                raise ValueError(_("'%s' for size '%s' does not describe a known size syntax.") % (size_string.decode(locale.getpreferredencoding()), size_name, ))
 
     def __parse_sort(self, sort_string):
         try:
@@ -536,7 +537,7 @@ class WebalbumDir(make.FileMakeObject):
         Returns the relative path to go from this directory to the path supplied
         as argument.
         '''
-        return pathutils.relative_path(self.path, path)
+        return os.path.relpath(path, self.path)
 
     def flattening_srcpath(self, srcdir_path):
         '''
@@ -593,7 +594,7 @@ class WebalbumDir(make.FileMakeObject):
 
 class SharedFiles(make.FileMakeObject):
 
-    def __init__(self, album, dest_dir):
+    def __init__(self, album, dest_dir, tpl_vars):
         self.path = os.path.join(dest_dir, DEST_SHARED_DIRECTORY_NAME)
         self.album = album
 
@@ -615,7 +616,8 @@ class SharedFiles(make.FileMakeObject):
 
             if self.album.tpl_loader.is_known_template_type(shared_file):
                 sf = genpage.SharedFileTemplate(album, shared_file,
-                                                shared_file_dest)
+                                                shared_file_dest,
+                                                tpl_vars)
                 self.expected_shared_files.append(sf.path)
             else:
                 sf = genfile.SharedFileCopy(shared_file, shared_file_dest)
@@ -822,6 +824,9 @@ class Album:
                 container_subdirs, container_subgals = dir_heap[container_dirname]
                 container_subdirs.append(source_dir)
                 container_subgals.append(destgal)
+            else:
+                # Use root config tpl vars for shared files
+                tpl_vars = destgal.tpl_vars
 
             if feed and source_dir.is_album_root():
                 feed.set_title(source_dir.human_name)
@@ -851,7 +856,7 @@ class Album:
             feed.make()
 
         # Force to check for unexpected files
-        SharedFiles(self, sane_dest_dir).make(True)
+        SharedFiles(self, sane_dest_dir, tpl_vars).make(True)
 
 
 # vim: ts=4 sw=4 expandtab
