@@ -17,6 +17,8 @@
 
 
 import os
+import posixpath
+import pathutils
 import sys
 import logging
 import urllib
@@ -117,7 +119,9 @@ class WebalbumPage(genfile.WebalbumFile):
         if srcdir_path != self.dir.source_dir.path:
             index_path = srcdir_path
         if index_path is not None:
-            link_target = self.dir.rel_path_to_src(index_path) + link_target
+            index_path = self.dir.rel_path_to_src(index_path)
+            index_path = pathutils.url_path(index_path)
+            link_target = posixpath.join(index_path, link_target)
 
         return self.url_quote(link_target)
 
@@ -205,11 +209,12 @@ class WebalbumBrowsePage(WebalbumPage):
             tpl_values['index_link'] = index_rel_dir + tpl_values['index_link']
 
         tpl_values['osize_links'] = self._get_osize_links(self.media.name)
-        tpl_values['rel_root'] = self.dir.source_dir.rel_root()
+        tpl_values['rel_root'] = self.dir.source_dir.rel_root() + '/'
 
         if self.dir.feed is not None:
-            tpl_values['feed_url'] = pathutils.relative_path(self.dir.path,
-                                                             self.dir.feed.path)
+            tpl_values['feed_url'] = os.path.relpath(self.dir.feed.path,
+                                                     self.dir.path)
+            tpl_values['feed_url'] = pathutils.url_path(tpl_values['feed_url'])
             tpl_values['feed_url'] = self.url_quote(tpl_values['feed_url'])
         else:
             tpl_values['feed_url'] = None
@@ -427,12 +432,13 @@ class WebalbumIndexPage(WebalbumPage):
 
         values.update(self._get_dir_info())
 
-        values['rel_root'] = self.dir.source_dir.rel_root()
+        values['rel_root'] = self.dir.source_dir.rel_root() + '/'
         values['rel_path'] = self.dir.source_dir.strip_root()
 
         if self.dir.feed is not None:
-            values['feed_url'] = pathutils.relative_path(self.dir.path,
-                                                         self.dir.feed.path)
+            values['feed_url'] = os.path.relpath(self.dir.feed.path,
+                                                 self.dir.path)
+            values['feed_url'] = pathutils.url_path(values['feed_url'])
             values['feed_url'] = self.url_quote(values['feed_url'])
         else:
             values['feed_url'] = None
@@ -489,9 +495,11 @@ class WebalbumFeed(make.FileMakeObject):
 
 class SharedFileTemplate(make.FileMakeObject):
 
-    def __init__(self, album, shared_tpl_name, shared_file_dest_tplname):
+    def __init__(self, album, shared_tpl_name, shared_file_dest_tplname,
+                       tpl_vars):
         self.album = album
         self.tpl = self.album.tpl_loader.load(shared_tpl_name)
+        self.tpl_vars = tpl_vars
 
         # Remove the 't' from the beginning of ext
         filename, ext = os.path.splitext(shared_file_dest_tplname)
@@ -506,7 +514,7 @@ class SharedFileTemplate(make.FileMakeObject):
     def build(self):
         logging.info(_("TPL %%SHAREDDIR%%/%s") % os.path.basename(self.path))
         logging.debug("(%s)" % self.path)
-        self.tpl.dump({}, self.path)
+        self.tpl.dump(self.tpl_vars, self.path)
 
 
 # vim: ts=4 sw=4 expandtab
