@@ -41,10 +41,14 @@ class File(make.FileSimpleDependency):
         if not path:
             path = self.path
 
-        return pathutils.relative_path(self.album.source_dir, path)
+        relative_path = os.path.relpath(path, self.album.source_dir)
+        if relative_path == '.':
+            return ''
+        else:
+            return relative_path
 
     def rel_root(self):
-        return pathutils.relative_path(self.path, self.album.source_dir)
+        return os.path.relpath(self.album.source_dir, self.path)
 
     def rel_path(self, from_dir, path=None):
         try:
@@ -55,7 +59,7 @@ class File(make.FileSimpleDependency):
         if path is None:
             path = self.path
 
-        return pathutils.relative_path(from_dir, path)
+        return os.path.relpath(path, from_dir)
 
     def is_subdir_of(self, dir, path=None):
         if path is None:
@@ -80,7 +84,7 @@ class File(make.FileSimpleDependency):
         while cur_path != self.album.source_dir:
             cur_path, tail = os.path.split(cur_path)
             album_level += 1
-            if cur_path == '/':
+            if pathutils.is_root(cur_path):
                 raise RuntimeError(_('Root not found'))
         return album_level
 
@@ -296,7 +300,7 @@ class Directory(File):
         while not found:
             if head == self.album.source_dir:
                 found = True
-            elif head == "/":
+            elif pathutils.is_root(head):
                 raise RuntimeError(_("Root not found"))
             else:
                 head, tail = os.path.split(head)
